document.addEventListener('DOMContentLoaded', () => {
  // Update slider values
  document.querySelectorAll('.slider').forEach(slider => {
    const valueDisplay = slider.nextElementSibling;
    slider.addEventListener('input', () => {
      valueDisplay.textContent = slider.value;
    });
  });

  // Universities data
  const universities = [
    { name: 'Tohoku University', rank: '101-150', fields: ['Medical Imaging', 'Complex Systems'] },
    { name: 'Osaka University', rank: '201-300', fields: ['Medical Engineering', 'System Simulation'] },
    { name: 'Nagoya University', rank: '301-400', fields: ['Complex Systems', 'Medical Imaging'] },
    { name: 'Hokkaido University', rank: '401-500', fields: ['System Simulation', 'Medical Engineering'] }
  ];

  // Populate universities
  const universityList = document.getElementById('universityList');
  universities.forEach(uni => {
    const div = document.createElement('div');
    div.className = 'field-card';
    div.innerHTML = `
      <h3>${uni.name}</h3>
      <p>World Rank: ${uni.rank}</p>
      <p>Key Fields: ${uni.fields.join(', ')}</p>
    `;
    universityList.appendChild(div);
  });

  // Analyze preferences
  document.getElementById('analyze').addEventListener('click', () => {
    const scores = {
      imaging: parseInt(document.getElementById('imaging').value),
      complex: parseInt(document.getElementById('complex').value),
      simulation: parseInt(document.getElementById('simulation').value),
      medical: parseInt(document.getElementById('medical').value)
    };

    const result = document.getElementById('result');
    const maxScore = Math.max(...Object.values(scores));
    const topFields = Object.entries(scores)
      .filter(([_, score]) => score === maxScore)
      .map(([field, _]) => {
        const fields = {
          imaging: 'Medical Imaging Recognition',
          complex: 'Complex System Studies',
          simulation: 'System Simulation',
          medical: 'Medical Aid Engineering'
        };
        return fields[field];
      });

    result.innerHTML = `
      <h3>Analysis Results</h3>
      <p>Based on your preferences, you show the strongest interest in:</p>
      <ul>
        ${topFields.map(field => `<li>${field}</li>`).join('')}
      </ul>
      <p>Consider exploring these fields further and reaching out to relevant professors at the universities listed below.</p>
    `;
    
    result.style.opacity = '0';
    result.style.display = 'block';
    setTimeout(() => result.style.opacity = '1', 10);
  });
});
